==> ah-form-builder-sample-0.6.19.tgz: package/es/components/app/fields-wrappers/Select.js <==
var _jsxFileName = "/var/apps/ah-form-builder/src/components/app/fields-wrappers/Select.js";
import React from 'react';
import Input from "../../../utils/inputs/TextInput";
import MultiSelect from "../../../utils/selects/MultiSelect";
import SearchableSelect from "../../../utils/selects/SearchableSelect";
import CheckboxGroup from '../../../utils/checkboxs/CheckboxGroup';
export default function SelectWrapper(props) {
  var defaultValue = null;

  if (props.data.config.isMultiple) {
    defaultValue = [];
  }

  var _React$useState = React.useState(defaultValue),
      value = _React$useState[0],
      setValue = _React$useState[1];

  var _React$useState2 = React.useState(false),
      other = _React$useState2[0],
      setOther = _React$useState2[1];

  var _React$useState3 = React.useState(''),
      otherValue = _React$useState3[0],
      setOtherValue = _React$useState3[1];

  var handleChange = function handleChange(e) {
    var newValue = e.target.value;

    if (props.data.config.isMultiple && newValue.includes(-1)) {
      setOther(true);
    } else if (!props.data.config.isMultiple && newValue === -1) {
      setOther(true);
    } else {
      setOther(false);
      setOtherValue('');
    }

    setValue(newValue);
  };

  var handleOtherChange = function handleOtherChange(e) {
    setOtherValue(e.target.value);
  };

  var options = [];

  if (props.data.config.optionReferenceId) {
    options = _.cloneDeep(props.predefined[props.data.config.optionReferenceId].options);
  }

  if (props.data.config.enableOther) {
    options.push({
      id: -1,
      name: 'Specify Others'
    });
  }

  if (props.data.config.isMultiple) {
    if (other) {
      return [/*#__PURE__*/React.createElement(MultiSelect, {
        label: props.data.name,
        placeholder: props.data.config.placeholder,
        helperText: props.data.config.helpText,
        required: props.data.config.isRequired,
        options: options,
        value: value,
        labelProp: "name",
        valueProp: "id",
        handleChange: handleChange,
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 44,
          columnNumber: 9
        }
      }), /*#__PURE__*/React.createElement(Input, {
        handleChange: handleOtherChange,
        value: otherValue,
        placeholder: "Specify Others",
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 55,
          columnNumber: 9
        }
      })];
    }

    return /*#__PURE__*/React.createElement(MultiSelect, {
      label: props.data.name,
      placeholder: props.data.config.placeholder,
      helperText: props.data.config.helpText,
      required: props.data.config.isRequired,
      options: options,
      value: value,
      labelProp: "name",
      valueProp: "id",
      handleChange: handleChange,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 63,
        columnNumber: 7
      }
    });
  } else {
    if (other) {
      return [/*#__PURE__*/React.createElement(SearchableSelect, {
        label: props.data.name,
        placeholder: props.data.config.placeholder,
        helperText: props.data.config.helpText,
        required: props.data.config.isRequired,
        labelProp: "name",
        valueProp: "id",
        options: options,
        value: value,
        handleChange: handleChange,
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 78,
          columnNumber: 9
        }
      }), /*#__PURE__*/React.createElement(Input, {
        handleChange: handleOtherChange,
        value: otherValue,
        placeholder: "Specify Others",
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 89,
          columnNumber: 9
        }
      })];
    }

    return /*#__PURE__*/React.createElement(SearchableSelect, {
      label: props.data.name,
      placeholder: props.data.config.placeholder,
      helperText: props.data.config.helpText,
      required: props.data.config.isRequired,
      labelProp: "name",
      valueProp: "id",
      options: options,
      value: value,
      handleChange: handleChange,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 97,
        columnNumber: 7
      }
    });
  }
}

==> ah-form-builder-sample-0.6.86.tgz: package/es/components/app/fields-wrappers/Select.js <==
var _jsxFileName = "/var/www/html/formbuilder/src/components/app/fields-wrappers/Select.js";
import React from 'react';
import Input from "../../../utils/inputs/TextInput";
import MultiSelect from "../../../utils/selects/MultiSelect";
import SearchableSelect from "../../../utils/selects/SearchableSelect";
import CheckboxGroup from '../../../utils/checkboxs/CheckboxGroup';
export default function SelectWrapper(props) {
  var defaultValue = [];

  var _React$useState = React.useState(defaultValue),
      value = _React$useState[0],
      setValue = _React$useState[1];

  var _React$useState2 = React.useState(false),
      other = _React$useState2[0],
      setOther = _React$useState2[1];

  var _React$useState3 = React.useState(''),
      otherValue = _React$useState3[0],
      setOtherValue = _React$useState3[1];

  var handleChange = function handleChange(e) {
    var newValue = e.target.value;

    if (props.data.config.isMultiple && newValue.includes(-1)) {
      setOther(true);
    } else if (!props.data.config.isMultiple && newValue === -1) {
      setOther(true);
    } else {
      setOther(false);
      setOtherValue('');
    }

    setValue(newValue);
  };

  var handleOtherChange = function handleOtherChange(e) {
    setOtherValue(e.target.value);
  };

  var options = [];

  if (props.data.config.optionReferenceId) {
    options = _.cloneDeep(props.predefined[props.data.config.optionReferenceId].options);
  }

  if (props.data.config.enableOther) {
    options.push({
      id: -1,
      name: 'Specify Others'
    });
  }

  if (props.data.config.isMultiple) {
    var _props$data2;

    if (other) {
      var _props$data;

      return [/*#__PURE__*/React.createElement(MultiSelect, {
        label: ((_props$data = props.data) == null ? void 0 : _props$data.locals) && Object.keys(props.data.locals).length !== 0 ? props.currentLang === 'en' ? props.data.name : props.data.locals.ar.name_ar : props.data.name,
        placeholder: props.data.config.placeholder,
        helperText: props.data.config.helpText,
        required: props.data.config.isRequired,
        options: options,
        value: value,
        labelProp: "name",
        valueProp: "id",
        handleChange: handleChange,
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 41,
          columnNumber: 9
        }
      }), /*#__PURE__*/React.createElement(Input, {
        handleChange: handleOtherChange,
        value: otherValue,
        placeholder: "Specify Others",
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 52,
          columnNumber: 9
        }
      })];
    }

    return /*#__PURE__*/React.createElement(MultiSelect, {
      label: ((_props$data2 = props.data) == null ? void 0 : _props$data2.locals) && Object.keys(props.data.locals).length !== 0 ? props.currentLang === 'en' ? props.data.name : props.data.locals.ar.name_ar : props.data.name,
      placeholder: props.data.config.placeholder,
      helperText: props.data.config.helpText,
      required: props.data.config.isRequired,
      options: options,
      value: value,
      labelProp: "name",
      valueProp: "id",
      handleChange: handleChange,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 60,
        columnNumber: 7
      }
    });
  } else {
    if (other) {
      return [/*#__PURE__*/React.createElement(SearchableSelect, {
        label: props.data.name,
        placeholder: props.data.config.placeholder,
        helperText: props.data.config.helpText,
        required: props.data.config.isRequired,
        labelProp: "name",
        valueProp: "id",
        options: options,
        value: value,
        handleChange: handleChange,
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 75,
          columnNumber: 9
        }
      }), /*#__PURE__*/React.createElement(Input, {
        handleChange: handleOtherChange,
        value: otherValue,
        placeholder: "Specify Others",
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 86,
          columnNumber: 9
        }
      })];
    }

    return /*#__PURE__*/React.createElement(SearchableSelect, {
      label: props.data.name,
      placeholder: props.data.config.placeholder,
      helperText: props.data.config.helpText,
      required: props.data.config.isRequired,
      labelProp: "name",
      valueProp: "id",
      options: options,
      value: value,
      handleChange: handleChange,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 94,
        columnNumber: 7
      }
    });
  }
}
